BuildContextExtensions extension

Extension on BuildContext to provide quick access to common properties.

on

Properties

bottomBarHeight double

Available on BuildContext, provided by the BuildContextExtensions extension

Returns the height of the bottom navigation bar (or safe area).
no setter
colorScheme ColorScheme

Available on BuildContext, provided by the BuildContextExtensions extension

Returns the current ColorScheme for the context.
no setter
isDarkMode bool

Available on BuildContext, provided by the BuildContextExtensions extension

Returns true if the current theme is dark mode.
no setter
screenHeight double

Available on BuildContext, provided by the BuildContextExtensions extension

Returns the screen height.
no setter
screenSize Size

Available on BuildContext, provided by the BuildContextExtensions extension

Returns the full screen Size.
no setter
screenWidth double

Available on BuildContext, provided by the BuildContextExtensions extension

Returns the screen width.
no setter
statusBarHeight double

Available on BuildContext, provided by the BuildContextExtensions extension

Returns the height of the status bar.
no setter
textTheme TextTheme

Available on BuildContext, provided by the BuildContextExtensions extension

Returns the current TextTheme for the context.
no setter