bottomBarHeight property
double
get
bottomBarHeight
Returns the height of the bottom navigation bar (or safe area).
Implementation
double get bottomBarHeight => MediaQuery.of(this).padding.bottom;
Returns the height of the bottom navigation bar (or safe area).
double get bottomBarHeight => MediaQuery.of(this).padding.bottom;