isDarkMode property
bool
get
isDarkMode
Returns true if the current theme is dark mode.
Implementation
bool get isDarkMode =>
MediaQuery.of(this).platformBrightness == Brightness.dark;
Returns true if the current theme is dark mode.
bool get isDarkMode =>
MediaQuery.of(this).platformBrightness == Brightness.dark;