daysInMonth property
int
get
daysInMonth
The number of days in the month for this date.
Implementation
int get daysInMonth => DateTime(year, month + 1, 0).day;
The number of days in the month for this date.
int get daysInMonth => DateTime(year, month + 1, 0).day;