routeSettings property

Object? get routeSettings

Gets the settings of the current route, if available.

Returns the RouteSettings of the route from ModalRoute.settings, or null if no route is currently active.

Implementation

Object? get routeSettings => ModalRoute.of(this)?.settings;