NumExtensions extension
Extension on num to provide currency formatting and time duration conversions.
- on
Properties
- hours → Duration
-
Available on num, provided by the NumExtensions extension
Converts the number to a Duration in hours.no setter - minutes → Duration
-
Available on num, provided by the NumExtensions extension
Converts the number to a Duration in minutes.no setter - seconds → Duration
-
Available on num, provided by the NumExtensions extension
Converts the number to a Duration in seconds.no setter
Methods
-
toCurrency(
{String symbol = '\$'}) → String -
Available on num, provided by the NumExtensions extension
Converts the number to a currency string with a customizable symbol.