isNotNullOrEmpty property
bool
get
isNotNullOrEmpty
Checks if the string is not null or empty after trimming whitespace.
Implementation
bool get isNotNullOrEmpty => trim().isNotEmpty;
Checks if the string is not null or empty after trimming whitespace.
bool get isNotNullOrEmpty => trim().isNotEmpty;