isNullOrEmpty property
bool
get
isNullOrEmpty
Checks if the string is null or empty after trimming whitespace.
Implementation
bool get isNullOrEmpty => trim().isEmpty;
Checks if the string is null or empty after trimming whitespace.
bool get isNullOrEmpty => trim().isEmpty;