arguments property
Object?
get
arguments
Gets the arguments passed to the current route, if available.
Returns the arguments from ModalRoute.settings.arguments, or null if no
arguments were passed or no route is currently active.
Implementation
Object? get arguments => ModalRoute.of(this)?.settings.arguments;