canPop method
Checks if the navigator can pop the current route.
Returns true if there is a previous route to return to, false otherwise.
Implementation
bool canPop() => Navigator.canPop(this);
Checks if the navigator can pop the current route.
Returns true if there is a previous route to return to, false otherwise.
bool canPop() => Navigator.canPop(this);