WidgetExtensions extension
Extension on Widget to add border, padding, and other styling helpers.
- on
Methods
-
borderAll(
Color color, {double width = 1.5, double radius = 0.0}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget with a container that has a border and optional corner radius. -
padding(
{double left = 0.0, double right = 0.0, double top = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Adds custom padding around the widget. -
paddingAll(
double value) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Adds equal padding on all sides. -
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Adds symmetric padding around the widget.